@@ -1,7 +1,7 @@
 /*
  * X Font Server for *.ttf Files
  *
- * $Id: xfstt.cc,v 1.14 2003/07/31 06:27:29 guillem Exp $
+ * $Id: xfstt.cc,v 1.18 2003/08/07 06:31:47 guillem Exp $
  *
  * Copyright (C) 1997-1999 Herbert Duerr
  * portions are (C) 1999 Stephen Carpenter and others
@@ -52,6 +52,7 @@
 #include <sys/types.h>
 #include <dirent.h>
 #include <string.h>
+#include <string>
 #include <ctype.h>
 
 #include <stdlib.h>
@@ -152,12 +153,16 @@ static int
 ttSyncDir(FILE *infoFile, FILE *nameFile, char *ttdir, int gslist)
 {
 	int nfonts = 0;
+	int ttdir_len = strlen(ttdir);
+
 	if (!gslist)
 		printf(_("xfstt: sync in directory \"%s/%s\"\n"), fontdir, ttdir);
+
 	DIR *dirp = opendir(".");
 
 	while (dirent *de = readdir(dirp)) {
 		int namelen = strlen(de->d_name);
+
 		if (namelen - 4 <= 0)
 			continue;
 		char *ext = &de->d_name[namelen - 4];
@@ -175,10 +180,8 @@ ttSyncDir(FILE *infoFile, FILE *nameFile, char *ttdir, int gslist)
 		if (!S_ISREG(statbuf.st_mode))
 			continue;
 
-		char pathName[256];	// XXX: remove constant path size
-		strcpy(pathName, ttdir);
-		strcat(pathName, "/");
-		strcat(pathName, de->d_name);
+		char pathName[ttdir_len + namelen + 2];
+		sprintf(pathName, "%s/%s", ttdir, de->d_name);
 
 		TTFont *ttFont = new TTFont(de->d_name, 1);
 		if (ttFont->badFont() || !ttFont) {
@@ -200,16 +203,18 @@ ttSyncDir(FILE *infoFile, FILE *nameFile, char *ttdir, int gslist)
 		fputc('\0', nameFile);
 
 		if (gslist)
-			printf("(%s)\t(/%s/%s)\t;\n",
+			printf("(%s)\t(%s/%s)\t;\n",
 			       fi.faceName, fontdir, pathName);
-		
-		pathName[0] = '-';
+
+		std::string xlfd_templ = "-";
 		if (*ttdir == '.')
-			strcpy(pathName + 1, "ttf");
+			xlfd_templ += "ttf";
 		else
-			strcpy(pathName + 1, ttdir);
-		info.xlfdLen = ttFont->getXLFDbase(pathName);
-		fwrite((void *)pathName, 1, info.xlfdLen, nameFile);
+			xlfd_templ += ttdir;
+
+		std::string xlfd = ttFont->getXLFDbase(xlfd_templ);
+		info.xlfdLen = xlfd.length();
+		fwrite((void *)xlfd.c_str(), 1, info.xlfdLen, nameFile);
 		fputc('\0', nameFile);
 
 		info.charSet = 'U';
@@ -239,10 +244,17 @@ ttSyncDir(FILE *infoFile, FILE *nameFile, char *ttdir, int gslist)
 static char *
 cachefile(const char *leafname)
 {
-	if (chdir(cachedir)) {
+	struct stat statbuf;
+
+	if (stat(cachedir, &statbuf)) {
 		fprintf(stderr, _("xfstt: \"%s\" does not exist!\n"), cachedir);
 		return 0;
 	}
+	if (!S_ISDIR(statbuf.st_mode)) {
+		fprintf(stderr, _("xfstt: \"%s\" is not a directory!\n"),
+			cachedir);
+		return 0;
+	}
 
 	long len = strlen(cachedir) + strlen(leafname) + 2;
 	long maxlen = pathconf(cachedir, _PC_PATH_MAX);
@@ -262,7 +274,7 @@ static int
 ttSyncAll(int gslist = 0)
 {
 	if (!gslist)
-		debug("TrueType synching\n");
+		debug("TrueType syncing\n");
 
 	if (chdir(fontdir)) {
 		fprintf(stderr, _("xfstt: \"%s\" does not exist!\n"), fontdir);
@@ -283,7 +295,7 @@ ttSyncAll(int gslist = 0)
 	FILE *nameFile = fopen(ttnamefilename, "wb");
 	delete ttinfofilename;
 	delete ttnamefilename;
-	
+
 	if (infoFile <= 0 || nameFile <= 0) {
 		fputs(_("xfstt: Cannot write to font database!\n"), stderr);
 		return -1;
@@ -411,7 +423,7 @@ listTTFNFonts(char *pattern, int index, char *buf)
 		while (--len > 0 && *(alias++) != '\"');
 		if (len <= 0)
 			return -1;
-		char* name = alias;
+		char *name = alias;
 		while (--len > 0 && *(alias++) != '\"');
 		*buf = alias - name - 1;
 		strncpy(buf + 1, name, *(U8 *)buf);
@@ -679,7 +691,7 @@ openXLFD(Rasterizer *raster, char *xlfdName, FontParams *fp, int fid)
 				fp->resolution[1] = xatoi(++p);
 				break;
 			case 13:
-				for (char* cp = p; *cp; ++cp)
+				for (char *cp = p; *cp; ++cp)
 					*cp = tolower(*cp);
 				encoding = Encoding::find(++p);
 				break;
@@ -726,7 +738,8 @@ openTTFdb()
 	}
 
 	char *ttinfofilename = cachefile(TTINFO_LEAF);
-	if (!ttinfofilename) return 0;
+	if (!ttinfofilename)
+		return 0;
 
 	int fd = open(ttinfofilename, O_RDONLY);
 	if (0 >= fd) {
